@@ -16,7 +16,7 @@
 #define CAIROMM_MINOR_VERSION 14
 
 /* Micro version number of cairomm. */
-#define CAIROMM_MICRO_VERSION 2
+#define CAIROMM_MICRO_VERSION 3
 
 /* Enable DLL-specific stuff only when not building a static library */
 #if !defined(__CYGWIN__) && \
@@ -28,8 +28,10 @@
 #ifdef CAIROMM_DLL
 # if defined(CAIROMM_BUILD)
 #  define CAIROMM_API __declspec(dllexport)
-# else
+# elif !defined (__GNUC__)
 #  define CAIROMM_API __declspec(dllimport)
+# else /* don't dllimport classes/methods on GCC/MinGW */
+#  define CAIROMM_API
 # endif
 /* Build a static or non-native-Windows library */
 #else
